/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.api.filter;

/**
 * Base-interface for blocking filters.
 * <p/>
 * Blocking filters are filters which returns a response to the client without contacting the specified
 * server. Typically used for blocking ad-sites such as "doubleclick.net".
 * <p/>
 * A filter-instance is not created for each request but is shared for all requests. Alle request-specific
 * data is parsed in the {@link BlockerFilterData} parameter to the {@link #process} method.
 */
public interface BlockerFilter
{
	/**
	 * if the method doesn't call {@link BlockerFilterData#send} or {@link BlockerFilterData#stream}
	 * then the filter is ignored, and the next-matching blocking filter is used.
	 * <p/>
	 * If no matching blocking filter sends data, then the processing continues as if no blocking filter matched.
	 * This enables the filters to take a closer look at the request before deciding to block the request or not.
	 */
	void process(BlockerFilterData data) throws Exception;
}