/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.api.filter;

import dk.vitality.glimmerblock.api.result.Headers;
import dk.vitality.glimmerblock.api.result.ResultData;

/**
 * Convenience base class for creating a {@link ContentFilter} which modifies text-based content such as html or xml.
 * It handles decoding the bytes using the charset specified from the server.
 */
abstract public class ContentTextFilter implements ContentFilter
{
	/**
	 * The content-type, e.g. "text/html".
	 */
	protected final String contentType;

	/**
	 * @param contentType MUST indicate UTF-8, e.g. "text/html; charset=UTF-8"
	 */
	protected ContentTextFilter(String contentType)
	{
		this.contentType = contentType;
	}

	public void process(ContentFilterData data) throws Exception
	{
		String txt = data.responseData.getContentAsText();
		txt = filterText(txt, data);
		Headers h = new Headers(data.responseData.headers.status,
				data.responseData.headers.statusMessage,
				contentType, null,
				data.responseData.headers.headerMap);
		data.send(new ResultData(h, txt));
	}

	/**
	 * Convenience method for modifying the content. Subclasses should override this method (only) rather
	 * than {@lonk #process}.
	 *
	 * @param txt  The content from the server.
	 * @param data The request specific parameters such as the request URL.
	 * @return The modified content.
	 */
	abstract protected String filterText(String txt, ContentFilterData data) throws Exception;
}