/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.api.result;

import java.net.HttpURLConnection;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * HeaderBuilder is to {@link Headers} as StringBuilder is to String.
 */
public class HeadersBuilder
{
	public int status;
	public String statusMessage;
	public String contentType = "text/plain", contentEncoding;

	private Map<String, List<String>> headers = new HashMap<String, List<String>>();

	/**
	 * Create using HTTP status 200 OK.
	 */
	public HeadersBuilder()
	{
		this(HttpURLConnection.HTTP_OK, "OK");
	}

	/**
	 * Create using the specified HTTP status.
	 *
	 * @param status        HTTP status code such as 404.
	 * @param statusMessage HTTP status message such as "OK".
	 */
	public HeadersBuilder(int status, String statusMessage)
	{
		this.status = status;
		this.statusMessage = statusMessage;
	}

	/**
	 * Adds an HTTP header. Duplicate headers are added instead of replaced to enable multiple Set-Cookie headers.
	 *
	 * @param nameLC The header name. <b>MUST BE LOWERCASE.</b>
	 * @param value  The header value.
	 */
	public void add(String nameLC, String value)
	{
		List<String> list = headers.get(nameLC);
		if (list == null) {
			list = new ArrayList<String>();
			headers.put(nameLC, list);
		}
		list.add(value);
	}

	/**
	 * Create a {@link Headers} instance, similar to {@link StringBuilder#toString}.
	 */
	public Headers toHeaders()
	{
		return new Headers(status, statusMessage, contentType, contentEncoding, headers);
	}
}
