/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.proxy.filter;

import dk.vitality.glimmerblock.api.filter.BlockerFilter;
import dk.vitality.glimmerblock.api.filter.BlockerFilterData;
import dk.vitality.glimmerblock.api.result.ResultData;

/**
 * Utility base class for creating blocking filters.
 */
public class AbstractBlockerFilterAdder
{
	public final DomainTreeSet filterSet;

	public AbstractBlockerFilterAdder(DomainTreeSet filterSet)
	{
		this.filterSet = filterSet;
	}

	/**
	 * Block the specified host/domain.
	 *
	 * @param hostPath See {@link DomainTree#add}
	 */
	protected void block(String hostPath)
	{
		filterSet.blockers.add(hostPath, simpleBlocker);
	}

	public static SimpleBlocker simpleBlocker = new SimpleBlocker();

	/**
	 * Simple blocker. Sends a simple 404 if the path indicates a flash movie,
	 * and a checkerboard GIF otherwise.
	 */
	public static class SimpleBlocker implements BlockerFilter
	{
		public void process(BlockerFilterData data) throws Exception
		{
			String path = data.requestUrl.getPath();
			if (path != null && path.endsWith(".swf"))
				data.send(ResultData.NOT_FOUND);
			else
				data.send(ResultData.BLOCKER_GIF);
		}
	}
}
