/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.proxy.filter;

import dk.vitality.glimmerblock.api.filter.BlockerFilter;
import dk.vitality.glimmerblock.api.filter.ContentFilter;
import dk.vitality.glimmerblock.api.util.Logger;

/**
 * Contains a set of DomainTree's.<p>
 * One tree for blocking requests so the remote server isn't contacted at all
 * (typically ad-sites such as doubleclick.net).
 * <p/>
 * A set of trees for different content-types so e.g. html-filters doesn't modify javascripts, images etc.
 * This makes most filters simpler as they don't have to check the content-type.
 */
public class DomainTreeSet
{
	public final Logger logger;

	/**
	 * Filters which blocks the request, i.e. is executed without obtaining anything from the remote server.
	 */
	public final DomainTree<BlockerFilter> blockers;

	/**
	 * Filters which modify the content when the Content-Type is text/html.
	 */
	public final DomainTree<ContentFilter> textHtml;

	/**
	 * Filters which modify the content when the Content-Type is text/xml such as RSS feeds.
	 */
	public final DomainTree<ContentFilter> textXml;

	public DomainTreeSet(Logger logger)
	{
		this.logger = logger;
		blockers = new DomainTree<BlockerFilter>(logger);
		textHtml = new DomainTree<ContentFilter>(logger);
		textXml = new DomainTree<ContentFilter>(logger);
	}
}
