/* Copyright (c) 2006-2008, Peter Speck / Vitality. All rights reserved.
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright
 *       notice, this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of Vitality nor the names of its contributors may be
 *       used to endorse or promote products derived from this software without
 *       specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY PETER SPECK / VITALITY AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL PETER SPECK / VITALITY AND CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
 * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR  SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED
 * OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package dk.vitality.glimmerblock.proxy.standardFilters;

import java.util.regex.Pattern;
import dk.vitality.glimmerblock.api.filter.ContentFilterData;
import dk.vitality.glimmerblock.api.filter.ContentTextHtmlFilter;
import dk.vitality.glimmerblock.api.filter.ContentTextXmlFilter;
import dk.vitality.glimmerblock.proxy.filter.AbstractContentFilterAdder;
import dk.vitality.glimmerblock.proxy.filter.DomainTreeSet;

/**
 * Contains a few innocent filters such as a mpeg download link on youtube pages.
 */
public class StandardContentFilters extends AbstractContentFilterAdder
{
	public StandardContentFilters(DomainTreeSet filterSet)
	{
		super(filterSet);
		addHtml(".dilbert.com", new ScriptZapper());
		addHtml(".youtube.com", new YoutubeFilter());
		//
		addXml("feeds.feedburner.com", new FeedBurnerFilter());
	}

	/**
	 * Adds a download link on the pages using javascript which is inserted on the pages.
	 */
	public static class YoutubeFilter extends ContentTextHtmlFilter
	{
		protected String filterHtml(String html, ContentFilterData data) throws Exception
		{
			return html +
					scriptFileContents("dk/vitality/glimmerblock/proxy/standardFilters/youtube.js");
		}
	}


	/**
	 * Removes all the "add social site bookmark" image(!) links which makes the page impressively slow.
	 */
	public static class FeedBurnerFilter extends ContentTextXmlFilter
	{
		protected String filterXml(String xml, ContentFilterData data) throws Exception
		{
			xml = links1RE.matcher(xml).replaceAll("<!-- GB zapped using feedburner1RE -->\n");
			xml = links2RE.matcher(xml).replaceAll("<!-- GB zapped using feedburner2RE -->\n");
			return xml;
		}

		private final static Pattern links1RE = Pattern.compile("" + // single line in xml
				"<a href=.http://feeds\\.feedburner\\.com/~f/\\S*?><img src=.http://feeds\\.feedburner\\.com/~f/.*");
		private final static Pattern links2RE = Pattern.compile("" + // single line in xml
				"&lt;a href=.http://feeds\\.feedburner\\.com/~f/\\S*?&gt;&lt;img src=.http://feeds\\.feedburner\\.com/~f/.*");
	}
}